==> dhall-lsp-server-1.0.11-12-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-lsp-server
version:              1.0.11
visibility:           public
id:                   dhall-lsp-server-1.0.11-FOWKRpTiXgyEsoNv7OYy30
key:                  dhall-lsp-server-1.0.11-FOWKRpTiXgyEsoNv7OYy30
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriel Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  3561ea16c8423eaad4288eabd177ef7f
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dhall-lsp-server-1.0.11
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dhall-lsp-server-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/dhall-lsp-server-1.0.11
hs-libraries:         HSdhall-lsp-server-1.0.11-FOWKRpTiXgyEsoNv7OYy30
depends:
    aeson-1.5.4.1-A0L815KAfIF5MogEzEmc2
    aeson-pretty-0.8.8-21J6iSSunyPGLOXcoweNHX base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-0.7.1.1-72cggqozPVh3J5wCw4ajUU
    dhall-1.36.0-16yHSWYRrlBFDQo8cmOt0Z
    dhall-json-1.7.3-D6rK1Q2ZGL5BzNl8YFm1hS directory-1.3.6.0
    filepath-1.4.2.1 haskell-lsp-0.23.0.0-Atj9zrJZSOFAnvhkD8lmdE
    hslogger-1.3.1.0-JTzwyYKWvXNKJ6MO7C22s2
    lens-4.19.2-CM7xks4zopx8m7aqAk8opQ
    lens-family-core-2.1.0-8Brfqh2QzxlSD99dQOYhI
    megaparsec-8.0.0-D6VketRFgbk9le2xfmDvBF mtl-2.2.2
    network-uri-2.6.3.0-6vWQyDUmR9F6Y6dEBYfPUD
    prettyprinter-1.7.0-F78MabeDMlDJBljAjR2kxa
    rope-utf16-splay-0.3.1.0-6zrInLFFmb5CSsTomj8qVN text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-KjldV6HJtaDB1Zm2KKQlBR
    uri-encode-1.5.0.7-2GtAGcFDgO6FWFbYVAXF6o

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-lsp-server-1.0.11-17-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-lsp-server
version:              1.0.11
visibility:           public
id:                   dhall-lsp-server-1.0.11-8aTzHr1NwLsDpcNXXRS30K
key:                  dhall-lsp-server-1.0.11-8aTzHr1NwLsDpcNXXRS30K
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriel Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  729196cce178e1a11e1481a6dadbb7da
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-8.10.2/site-local/dhall-lsp-server-1.0.11
library-dirs:         /usr/lib/ghc-8.10.2/site-local/dhall-lsp-server-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/dhall-lsp-server-1.0.11
hs-libraries:         HSdhall-lsp-server-1.0.11-8aTzHr1NwLsDpcNXXRS30K
depends:
    aeson-1.5.4.1-L4blGMy4f2B3cvSeFwSnLz
    aeson-pretty-0.8.8-EZofP3qPfn85SUFSLLPAQI base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-0.7.1.1-3wgwb3HHgZGHXyhFfYsXMU
    dhall-1.36.0-HE8bcUsoMj2H69yPr1TU8O
    dhall-json-1.7.3-4hRd8hXgOCEIqjX9S6XT7A directory-1.3.6.0
    filepath-1.4.2.1 haskell-lsp-0.23.0.0-IpG9ALRUPNw3js2EZkB4tp
    hslogger-1.3.1.0-Bankm4oY7sxQX2xHVw43c
    lens-4.19.2-IhearE01tR9bjzWegWEUS
    lens-family-core-2.1.0-8Brfqh2QzxlSD99dQOYhI
    megaparsec-8.0.0-7TuU754CNavKU2kzAe3C75 mtl-2.2.2
    network-uri-2.6.3.0-KPpuEk5oPu0AppXKt8UbbT
    prettyprinter-1.7.0-92a7EfIoLDDAFKmhMFGQ0Q
    rope-utf16-splay-0.3.1.0-Lq7CdNqcmUYDolqqBgJYgL text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-E55HH0rr5oHcQHLhHgXKG
    uri-encode-1.5.0.7-FubVfABHCQErDbZexAb7J

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
